@@ -40,12 +40,10 @@ use CGI::Mungo::Response;
 use CGI::Mungo::Session;	#for session management
 use CGI::Mungo::Request;
 use Carp;
-our $VERSION = "1.2";
+our $VERSION = "1.4";
 #########################################################
 
-=pod
-
-=item new()
+=item new(\%options)
 
 	my $options = {
 		'responsePlugin' => 'Some::Class',
@@ -85,6 +83,7 @@ sub new{
 	my $response = $m->getResponse();
 
 Returns an instance of the response plugin object, previously defined in the constructor options.
+See L<CGI::Mungo::Response> for more details.
 
 =cut
 
@@ -99,6 +98,10 @@ sub getResponse{
 
 =item getSession()
 
+	my $session = $m->getSession();
+
+Returns an instance of the L<CGI::Mungo::Session> object.
+
 =cut
 
 ###########################################################
@@ -112,6 +115,10 @@ sub getSession{
 
 =item getRequest()
 
+	my $request = $m->getRequest();
+
+Returns an instance of the L<CGI::Mungo::Request> object.
+
 =cut
 
 ###########################################################
@@ -125,6 +132,18 @@ sub getRequest{
 
 =item setActions()
 
+	my %actions = (
+		'default' => \&showMenu().
+		'list' => \%showList() 
+	)
+	$m->setActions(\%actions);
+
+Sets the actions of the web application using a hash reference. The names of the keys in the hash
+reference will match the value of the given "action" form field from the current request. Hash reference values
+can be references to subs or annoymous subs.
+
+An action of 'default' can be used when a visitor does not request a specific action.
+
 =cut
 
 ###########################################################
@@ -139,6 +158,11 @@ sub setActions{
 
 =item getAction()
 
+	my $action = $m->getAction();
+
+Returns the curent action that the web application is performing. This is the current value of the "action"
+request form field.
+
 =cut
 
 ###########################################################
@@ -159,6 +183,11 @@ sub getAction{
 
 =item run()
 
+	$m->run();
+
+This methood is required for the web application to deal with the current request.
+It should be called after any setup is done.
+
 =cut
 
 ###########################################################
@@ -182,6 +211,24 @@ sub run{	#run the code for the given action
 	$response->display();	#display the output to the browser
 	return 1;
 }
+#########################################################
+
+=pod
+
+=item getThisUrl()
+
+	my $url = $m->getThisUrl();
+
+Returns the full URL for the current script.
+
+=cut
+
+###########################################################
+sub getThisUrl{
+	my $self = shift;
+	my $url = $ENV{'SCRIPT_URI'};
+	return $url;
+}
 ###########################################################
 # Private methods
 ###########################################################
@@ -193,7 +240,7 @@ sub _init{	#things to do when this object is created
 	my $response = $self->getResponse();
 	my $session = $self->getSession();
 	my $existingSession = 0;
-	if($session->read()){	#cehck for an existing session
+	if($session->read()){	#check for an existing session
 		if($session->validate()){
 			$existingSession = 1;
 			$self->log("we have an existing session");
@@ -240,6 +287,27 @@ sub _getOption{
 
 =back
 
+=head1 CONFIGURATION SUMMARY
+
+The following list gives a summary of each Mungo 
+configuration options. 
+
+=head3 responsePlugin
+
+A scalar string consisting of the response class to use.
+
+See L<CGI::Mungo::Response::Base> for details on how to create your own response class, or
+a list of response classes provided in this package.
+
+=head3 checkReferer
+
+Flag to indicate if referer checking should be performed. When enabled an
+error will raised when the referer is not present or does not contain the server's
+hostname.
+
+This option is enabled by default.
+
+
 =head1 Notes
 
 To change the session prefix characters use the following code at the top of your script:
@@ -259,5 +327,6 @@ Copyright (c) 2009 MacGyveR. All rights reserved.
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
+
 ###########################################################
 return 1;
