@@ -98,6 +98,18 @@ sub _getContent{
 
 =back
 
+=head1 Author
+
+MacGyveR <dumb@cpan.org>
+
+Development questions, bug reports, and patches are welcome to the above address
+
+=head1 Copyright
+
+Copyright (c) 2009 MacGyveR. All rights reserved.
+
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
 =cut
 
 ##################################################################################
