@@ -1,6 +1,29 @@
 #Session functions
 #mt	20070113	cookies should now expire
 package CGI::Mungo::Session;
+
+=pod
+
+=head1 NAME
+
+CGI::Mungo::Session - Session class
+
+=head1 SYNOPSIS
+
+	my $s = $mungo->getSession();
+	$s->setVar('name', 'value');
+	my $var = $s->getVar('name');
+
+=head1 DESCRIPTION
+
+Class to deal with session management.
+
+=head1 METHODS
+
+=over 4
+
+=cut
+
 use strict;
 use warnings;
 use Digest::MD5;
@@ -24,8 +47,6 @@ sub validate{	#runs the defined sub to see if this sesion is validate
 	if($self->getVar('remoteIp')){
 		if($self->getVar('remoteIp') eq $ENV{'REMOTE_ADDR'}){
 			if($self->getVar('scriptPath') && $self->getVar('scriptPath') eq $ENV{'SCRIPT_NAME'}){
-				#print STDERR "$0: Session ip " . $self->getVar('remoteIp') . " = " . $ENV{'REMOTE_ADDR'} . "\n"; 
-				#print STDERR "$0: Session path " . $self->getVar('scriptPath') . " = " . $ENV{'SCRIPT_NAME'} . "\n"; 
 				return 1;
 			}
 			else{
@@ -41,17 +62,28 @@ sub validate{	#runs the defined sub to see if this sesion is validate
 	}
 	return 0;
 }
+################################################################################################################
+
+=item setVar()
+
+	$s->setVar('name', 'value');
+
+Takes two arguments, first the name of the variable then the value of the variable to store.
+
+=cut
+
 ##########################################################################################################################
 sub setVar{	#stores a variable in the session
 	my($self, $name, $value) = @_;
 	$self->_storeVar($name, $value);
-	$self->_write();
-	return 1;
+	return $self->_write();
 }
 ##########################################################################################################################
 sub getVar{	#gets a stored variable from the session
 	my($self, $name) = @_;
-	if(defined($self->{'vars'}->{$name})){return $self->{'vars'}->{$name};}
+	if(defined($self->{'vars'}->{$name})){
+		return $self->{'vars'}->{$name};
+	}
 	else{return undef;}
 }
 ###########################################################################################################################
@@ -76,6 +108,24 @@ sub getId{	#returns the session id
 	my $self = shift;
 	return $self->{'id'};
 }
+##############################################################################################################
+
+=item create()
+
+	$response = $wf->getResponse();
+	my $hashref = {
+		username => "bob"
+	};
+	$s->create($hashref, $response);
+
+Creates a new session for the visitor.
+
+This saves the contents of the given hash reference into the session.
+
+The correct Set-Cookie header will be issued through the provided L<CGI::Mungo::Response> object.
+
+=cut
+
 ##############################################################################################################
 sub create{	#creates a server-side cookie for the session
 	my($self, $hash_p, $response) = @_;
@@ -84,27 +134,31 @@ sub create{	#creates a server-side cookie for the session
 	my $ctx = Digest::MD5->new;
 	$ctx->add($sessionId);
 	$sessionId = $self->_getPrefix() . $ctx->hexdigest;
-	if(open(SSIDE, ">/tmp/$sessionId")){
-		close(SSIDE);
-		$self->setId($sessionId);	#remember the session id
-		#set some initial values
-		$self->setVar('remoteIp', $ENV{'REMOTE_ADDR'});
-		$self->setVar('scriptPath', $ENV{'SCRIPT_NAME'});
-		$result = 1;
+	
+	$self->setId($sessionId);	#remember the session id
+	#set some initial values
+	$self->setVar('remoteIp', $ENV{'REMOTE_ADDR'});
+	$self->setVar('scriptPath', $ENV{'SCRIPT_NAME'});
+	while(my($name, $value) = each(%{$hash_p})){	#save any user provided variables
+		$self->setVar($name, $value);
+	}
+	if(!$self->getError()){	#all ok so far
+		my $domain = $ENV{'HTTP_HOST'};	#use the full domain name here
 		if($response){
-			my $cookie = &Set_Cookie(NAME => 'SESSION', VALUE => $sessionId, EXPIRE => 0);
+			my $cookie = &Set_Cookie(NAME => 'SESSION', VALUE => $sessionId, EXPIRE => 0, DOMAIN => $domain);
 			if($cookie =~ m/^([^ ]+): (.+)$/){
 				$response->header($1 => $2);
+				$result = 1;
 			}
 			else{
 				$self->setError("Invalid cookie line: $cookie");
 			}
 		}
 		else{	#old method if it is still used
-			print &Set_Cookie(NAME => 'SESSION', VALUE => $sessionId, EXPIRE => 0);
+			print &Set_Cookie(NAME => 'SESSION', VALUE => $sessionId, EXPIRE => 0, DOMAIN => $domain);
+			$result = 1;
 		}
 	}
-	else{$self->setError("Cant create session: $!");}
 	return $result;
 }
 ##############################################################################################################
@@ -114,24 +168,34 @@ sub read{	#read an existing session
 	my $sessionId = $self->_getCookie("SESSION");	#get the session id from the browser
 	if(defined($sessionId)){	#got a sessionid of some sort
 		my $prefix = $self->_getPrefix();
-		if($sessionId =~ m/^$prefix[a-f0-9]+$/){	#filename valid
-			if(open(SSIDE, "</tmp/$sessionId")){	#try to open the session file
+		if($sessionId =~ m/^($prefix[a-f0-9]+)$/){	#filename valid
+			if(open(SSIDE, "</tmp/" . $1)){	#try to open the session file
 				my $contents = "";
 				while(<SSIDE>){	#read each line of the file
 					$contents .= $_;
 				}
 				close(SSIDE);
-				my $VAR1;	#the session contents var
-				{
-					eval $contents;
+				if($contents =~ m/^(\$VAR1 = \{.+\};)$/m){	#check session contents
+					my $validContents = $1; #untaint variable
+					my $VAR1;	#the session contents var
+					{
+						eval $validContents;
+					}
+					$self->{'vars'} = $VAR1;
+					$result = 1;
+					$self->setId($sessionId);	#remember the session id
+				}
+				else{
+					$self->setError("Session contents invalid");
 				}
-				$self->{'vars'} = $VAR1;
-				$result = 1;
-				$self->setId($sessionId);	#remember the session id
 			}
-			else{$self->setError("Cant open session file: $!");}
+			else{
+				$self->setError("Cant open session file: $!");
+			}
+		}
+		else{
+			$self->setError("Session ID invalid: $sessionId");
 		}
-		else{$self->setError("Session ID invalid: $sessionId");}
 	}
 	return $result;
 }
@@ -195,7 +259,9 @@ sub _write{	#writes a server-side cookie for the session
 			$Data::Dumper::Toaster = 'toast';
 			$Data::Dumper::Indent = 0;	#turn off formatting
 			my $dump = Dumper $self->{'vars'};
-			print SSIDE $dump;
+			if($dump){	#if we have any data
+				print SSIDE $dump;
+			}
 			close(SSIDE);
 		}
 		else{$self->setError("Cant write session: $!");}
@@ -221,7 +287,7 @@ sub _getCookie{	#returns the value of a cookie
 ##########################################################################################################################
 sub _storeVar{	#stores a variable in the session
 	my($self, $name, $value) = @_;
-	if(!$value){	#remove the var
+	if(!defined($value)){	#remove the var
 		if($self->{'vars'}){	
 			my %vars = %{$self->{'vars'}};
 			delete $vars{$name};
@@ -238,5 +304,27 @@ sub _getPrefix{	#this should be a config option
 	return $prefix;
 }
 #####################################################################################################################
+
+=pod
+
+=back
+
+=head1 Notes
+
+=head1 Author
+
+MacGyveR <dumb@cpan.org>
+
+Development questions, bug reports, and patches are welcome to the above address
+
+=head1 Copyright
+
+Copyright (c) 2009 MacGyveR. All rights reserved.
+
+This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
+=cut
+
+##########################################
 return 1;
 END {}
